# قیمت لحظه‌ای تقریبا همه چیز! | Gheymat

  

کتابخانه‌ای برای دریافت قیمت ارزها و طلا و...
اگر به دردت خورد و اگر دوس داشتی برام یه کافی بخر 😁
https://www.coffeebede.com/mrrobat

![Downloads](https://static.pepy.tech/personalized-badge/gheymat?period=total&units=international_system&left_color=black&right_color=green&left_text=Downloads)

## آخرین آپدیت
#### در currency این موارد وجود دارد:
- قیمت دلار | USD
- قیمت پوند | GBP
#### در crypto این موارد وجود دارد:
- قیمت بیت‌کوین | BTC


## نصب
```bash
pip install gheymat
```

## استفاده
```python
from gheymat.currency import USD #or GBP

dollar_price = USD(toman=True)
print(dollar_price)
```
